@@ -1,5 +1,5 @@
 ######################################################################
-# $Id: CacheUtils.pm,v 1.20 2001/04/25 22:22:04 dclinton Exp $
+# $Id: CacheUtils.pm,v 1.23 2001/09/10 14:47:24 dclinton Exp $
 # Copyright (C) 2001 DeWitt Clinton  All Rights Reserved
 #
 # Software distributed under the License is distributed on an "AS
@@ -23,7 +23,7 @@ use Carp;
 use Digest::MD5 qw( md5_hex );
 use Exporter;
 use File::Path qw( mkpath );
-use File::Spec::Functions qw( catdir catfile splitdir splitpath tmpdir );
+use File::Spec::Functions;
 use Storable qw( nfreeze thaw dclone );
 
 @ISA = qw( Exporter );
@@ -47,6 +47,7 @@ use Storable qw( nfreeze thaw dclone );
                  Recursively_List_Files_With_Paths
                  Recursively_Remove_Directory
                  Remove_File
+                 Remove_Directory
                  Restore_Shared_Hash_Ref
                  Restore_Shared_Hash_Ref_With_Lock
                  Split_Word
@@ -72,7 +73,8 @@ my $UNTAINTED_PATH_REGEX = qr{^([-\@\w\\\\~./:]+|[\w]:[-\@\w\\\\~./]+)$};
 my %_Expiration_Units = ( map(($_,             1), qw(s second seconds sec)),
                           map(($_,            60), qw(m minute minutes min)),
                           map(($_,         60*60), qw(h hour hours)),
-                          map(($_,      60*60*24), qw(w week weeks)),
+                          map(($_,      60*60*24), qw(d day days)),
+                          map(($_,    60*60*24*7), qw(w week weeks)),
                           map(($_,   60*60*24*30), qw(M month months)),
                           map(($_,  60*60*24*365), qw(y year years)) );
 
@@ -285,13 +287,13 @@ sub Extract_Parent_Directory
   defined( $directory ) or
     croak( "directory required" );
 
-  my @directories = splitdir( $directory );
+  my @directories = File::Spec->splitdir( $directory );
 
   pop @directories;
 
   return undef unless @directories;
 
-  my $parent_directory = catdir( @directories );
+  my $parent_directory = File::Spec->catdir( @directories );
 
   return $parent_directory;
 }
@@ -312,6 +314,8 @@ sub Create_Directory
 
   umask( $optional_new_umask ) if defined $optional_new_umask;
 
+  $directory =~ s|/$||;
+
   mkpath( $directory, 0, $DIRECTORY_MODE );
 
   -d $directory or
@@ -379,7 +383,7 @@ sub Make_Path
 {
   my ( $path, $optional_new_umask ) = @_;
 
-  my ( $volume, $directory, $filename ) = splitpath( $path );
+  my ( $volume, $directory, $filename ) = File::Spec->splitpath( $path );
 
   return $SUCCESS unless $directory;
 
@@ -494,7 +498,7 @@ sub Remove_File
   my ( $filename ) = @_;
 
   defined( $filename ) or
-    croak( "path required" );
+    croak( "directory required" );
 
   if ( -f $filename )
   {
@@ -508,6 +512,28 @@ sub Remove_File
 }
 
 
+
+# remove a directory
+
+sub Remove_Directory
+{
+  my ( $directory ) = @_;
+
+  defined( $directory ) or
+    croak( "directory required" );
+
+  if ( -d $directory )
+  {
+    # We don't catch the error, because this may fail if two
+    # processes are in a race and try to remove the object
+
+    rmdir( $directory );
+  }
+
+  return $SUCCESS;
+}
+
+
 # list the names of the subdirectories in a given directory, without the
 # full path
 
@@ -646,16 +672,16 @@ sub Recursively_Remove_Directory
     {
       my $untainted_path_to_dirent = Untaint_Path( $path_to_dirent );
 
-      unlink( $untainted_path_to_dirent ) or
-        croak( "Couldn't unlink( $untainted_path_to_dirent ): $!\n" );
+      Remove_File( $untainted_path_to_dirent ) or
+        croak( "Couldn't Remove_File( $untainted_path_to_dirent ): $!\n" );
     }
   }
 
   my $untainted_root = Untaint_Path( $root ) or
     croak( "Couldn't untain root" );
 
-  rmdir( $untainted_root ) or
-    croak( "Couldn't rmdir $untainted_root: $!" );
+  Remove_Directory( $untainted_root ) or
+    croak( "Couldn't Remove_Directory( $untainted_root ): $!" );
 
   return $SUCCESS;
 }
@@ -777,7 +803,7 @@ sub Build_Object
 
 sub Get_Temp_Directory
 {
-  my $tmpdir = tmpdir( ) or
+  my $tmpdir = File::Spec->tmpdir( ) or
     croak( "No tmpdir on this system.  Bugs to the authors of File::Spec" );
 
   return $tmpdir;
